==> deepin-movie-reborn_5.7.4.orig.tar.xz: deepin-movie-reborn-5.7.4/src/widgets/burst_screenshots_dialog.h <==
/* 
 * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
#ifndef _DMR_BURST_SCREENSHOTS_DIALOG_H
#define _DMR_BURST_SCREENSHOTS_DIALOG_H 

#include <QtWidgets>
#include <DDialog>
#include <DTitlebar>

DWIDGET_USE_NAMESPACE

namespace dmr {
class PlayerEngine;
class PlayItemInfo;

class ThumbnailFrame: public QLabel { 
    Q_OBJECT
public:
    ThumbnailFrame(QWidget* parent) :QLabel(parent) {
        setFixedSize(178, 100);
        auto e = new QGraphicsDropShadowEffect(this);
        e->setColor(QColor(0, 0, 0, 255 * 2 / 10));
        e->setOffset(0, 2);
        e->setBlurRadius(4);
        setGraphicsEffect(e);
    }
};


class BurstScreenshotsDialog: public DAbstractDialog {
    Q_OBJECT
public:
    BurstScreenshotsDialog(const PlayItemInfo& pif);
    void updateWithFrames(const QList<QPair<QImage, qint64>>& frames);

    QString savedPosterPath();

public slots:
    int exec() override;
    void saveShootings();
    void savePoster();

private:
    QGridLayout *_grid {nullptr};
    QPushButton *_saveBtn {nullptr};
    QList<QPair<QImage, qint64>> _thumbs;
    QString _posterPath;
    DTitlebar* m_titlebar;
};
}

#endif /* ifndef _DMR_BURST_SCREENSHOTS_DIALOG_H */

==> deepin-movie-reborn_5.7.6.165.orig.tar.xz: deepin-movie-reborn-5.7.6.165/src/widgets/burst_screenshots_dialog.h <==
/*
 * (c) 2017, Deepin Technology Co., Ltd. <support@deepin.org>
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 3 of the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * is provided AS IS, WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, and
 * NON-INFRINGEMENT.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, see <http://www.gnu.org/licenses/>.
 *
 * In addition, as a special exception, the copyright holders give
 * permission to link the code of portions of this program with the
 * OpenSSL library under certain conditions as described in each
 * individual source file, and distribute linked combinations
 * including the two.
 * You must obey the GNU General Public License in all respects
 * for all of the code used other than OpenSSL.  If you modify
 * file(s) with this exception, you may extend this exception to your
 * version of the file(s), but you are not obligated to do so.  If you
 * do not wish to do so, delete this exception statement from your
 * version.  If you delete this exception statement from all source
 * files in the program, then also delete it here.
 */
#ifndef _DMR_BURST_SCREENSHOTS_DIALOG_H
#define _DMR_BURST_SCREENSHOTS_DIALOG_H

#include <QtWidgets>
#include <DDialog>
#include <DTitlebar>

DWIDGET_USE_NAMESPACE

namespace dmr {
class PlayItemInfo;

class ThumbnailFrame: public QLabel
{
    Q_OBJECT
public:
    ThumbnailFrame(QWidget *parent) : QLabel(parent)
    {
        setFixedSize(178, 100);
        auto e = new QGraphicsDropShadowEffect(this);
        e->setColor(QColor(0, 0, 0, 255 * 2 / 10));
        e->setOffset(0, 2);
        e->setBlurRadius(4);
        setGraphicsEffect(e);
    }
};


class BurstScreenshotsDialog: public DAbstractDialog
{
    Q_OBJECT
public:
    BurstScreenshotsDialog(const PlayItemInfo &pif);
    void updateWithFrames(const QList<QPair<QImage, qint64>> &frames);

    QString savedPosterPath();

public slots:
    int exec() override;
    void saveShootings();
    void savePoster();

private:
    QGridLayout *_grid {nullptr};
    QPushButton *_saveBtn {nullptr};
    QList<QPair<QImage, qint64>> _thumbs;
    QString _posterPath;
    DTitlebar *m_titlebar;
};
}

#endif /* ifndef _DMR_BURST_SCREENSHOTS_DIALOG_H */
